==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtCollectionLiteralExpressionElementType.kt <==
/*
 * Copyright 2010-2023 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.psi.stubs.StubElement
import ksp.com.intellij.psi.stubs.StubInputStream
import ksp.com.intellij.psi.stubs.StubOutputStream
import ksp.org.jetbrains.annotations.NonNls
import ksp.org.jetbrains.kotlin.psi.KtClassLiteralExpression
import ksp.org.jetbrains.kotlin.psi.KtCollectionLiteralExpression
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinClassLiteralExpressionStub
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinCollectionLiteralExpressionStub
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinClassLiteralExpressionStubImpl
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinCollectionLiteralExpressionStubImpl

class KtCollectionLiteralExpressionElementType(@NonNls debugName: String) :
    KtStubElementType<KotlinCollectionLiteralExpressionStub, KtCollectionLiteralExpression>(
        debugName,
        KtCollectionLiteralExpression::class.java,
        KotlinCollectionLiteralExpressionStub::class.java
    ) {
    override fun serialize(stub: KotlinCollectionLiteralExpressionStub, dataStream: StubOutputStream) {}

    override fun deserialize(dataStream: StubInputStream, parentStub: StubElement<*>?): KotlinCollectionLiteralExpressionStub {
        return KotlinCollectionLiteralExpressionStubImpl(parentStub)
    }

    override fun createStub(psi: KtCollectionLiteralExpression, parentStub: StubElement<*>?): KotlinCollectionLiteralExpressionStub {
        return KotlinCollectionLiteralExpressionStubImpl(parentStub)
    }
}

==> symbol-processing-aa-embeddable-2.2.0-2.0.2-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtCollectionLiteralExpressionElementType.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.psi.stubs.StubElement
import ksp.com.intellij.psi.stubs.StubInputStream
import ksp.com.intellij.psi.stubs.StubOutputStream
import ksp.org.jetbrains.annotations.NonNls
import ksp.org.jetbrains.kotlin.psi.KtCollectionLiteralExpression
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinCollectionLiteralExpressionStub
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinCollectionLiteralExpressionStubImpl

class KtCollectionLiteralExpressionElementType(@NonNls debugName: String) :
    KtStubElementType<KotlinCollectionLiteralExpressionStub, KtCollectionLiteralExpression>(
        debugName,
        KtCollectionLiteralExpression::class.java,
        KotlinCollectionLiteralExpressionStub::class.java
    ) {
    override fun serialize(stub: KotlinCollectionLiteralExpressionStub, dataStream: StubOutputStream) {
        dataStream.writeVarInt(stub.innerExpressionCount)
    }

    override fun deserialize(dataStream: StubInputStream, parentStub: StubElement<*>?): KotlinCollectionLiteralExpressionStub {
        val innerExpressionCount = dataStream.readVarInt()
        return KotlinCollectionLiteralExpressionStubImpl(
            parent = parentStub,
            innerExpressionCount = innerExpressionCount,
        )
    }

    override fun createStub(psi: KtCollectionLiteralExpression, parentStub: StubElement<*>?): KotlinCollectionLiteralExpressionStub {
        return KotlinCollectionLiteralExpressionStubImpl(
            parent = parentStub,
            innerExpressionCount = psi.innerExpressions.size,
        )
    }
}
